/*
 * app_config.h
 *
 *  Created on: 30/04/2015
 *      Author: Erick Castillo
 */

#ifndef APP_CONFIG_H_
#define APP_CONFIG_H_

#include <stdint.h>
#include <math.h>
#include <stdbool.h>
#include <time.h>


/*****************************************************************************
 *  Global Definitions
 *****************************************************************************/
#define DEBUG_ENERGY			1				// Activate the energy profiler
#define DEBUG_USART				1				// Use USART for debugging (can't be active together with LCD)
#define DEBUG_DISPLAY			!DEBUG_USART	// Use LCD for debugging (can't be active together with USART)
#define DEBUG_DC				0				// Test DC algorithm
#define DEBUG_RADIO				1				// Test radio packets
#define DEBUG_SYNC				0				// Test node's clocks

#define LED_ACTIVE				7
#define LED_TRANSMIT			6

#define NODE_ID					0x01			// ID from 0x01-0xFF

#define PARAM_SYNC_PERIOD		30				// Period of clock synchronization in mins
#define PARAM_DC_PERIOD			60				// Period for duty cycle in secs

#define MAX_BATTERY_VOLT		3400			// Maximum voltage for application
#define MIN_BATTERY_VOLT		2000			// Minimum voltage for application, should be higher than BOD threshold (max 1.96V)
#define INIT_BATTERY_VOLT		3300			// Initial battery level
#define INIT_BATTERY_LEVEL		(float_t)(INIT_BATTERY_VOLT - MIN_BATTERY_VOLT)\
									/ (MAX_BATTERY_VOLT - MIN_BATTERY_VOLT)

#define APP_MIN_DC				4				// Minimum duty cycle for sensor node
#define APP_MIN_DC_TX			5				// Minimum duty cycle for transmission of data packets
#define APP_MAX_DC				99				// Maximum duty cycle for sensor node
#define APP_INIT_DC				10				// Initial duty cycle for sensor node

// Packet match (1) + Length (1) + Source ID (1) + Packet type (1) + Data
#define NODE_PAYLOAD_SIZE		4u + sizeof(uint32_t) + sizeof(int32_t) + sizeof(uint8_t)
#define SYNC_PAYLOAD_SIZE		4u + sizeof(time_t)

#define CLOCK_INIT_VALUE		1420070400		// Number of seconds since midnight January 1, 2015
#define	CLOCK_INIT_DELAY		150				// Initialization delay


/*****************************************************************************
 *  Global Typedefs & Enums
 *****************************************************************************/
typedef struct
{
	uint32_t rhData;
	int32_t tempData;
} sensorData;

typedef struct
{
	sensorData sensor_data;
	uint8_t dc;
} nodeData;

typedef enum
{
	NODE_DATA,
	SYNC_DATA
} radioPkt_type;

typedef union
{
	nodeData node_data;
	time_t cur_time;
} radioPkt_payload;

typedef struct
{
	uint8_t length;
	uint8_t src_id;
	uint8_t dest_id;
	radioPkt_type type;
	radioPkt_payload payload;
} radioPkt_data;


/*****************************************************************************
 *  Global Function Declarations
 *****************************************************************************/
void setLED(uint8_t led);
void clearLED(uint8_t led);

time_t getTime(void);
void setTime(time_t new_time, uint32_t offset_ms);
void startClock(void);
void stopClock(void);


#endif /* APP_CONFIG_H_ */
