/*
 * communication.h
 *
 *  Created on: 26/05/2015
 *      Author: Erick Castillo
 */

#ifndef COMMUNICATION_H_
#define COMMUNICATION_H_

#include "app_config.h"


/******************************************************************************
 * Global Definitions
 *****************************************************************************/
#define MAX_NETWORK_NODES		256												// Maximum number of nodes which can be addressed
#define CLK_INIT_TIMEOUT		1800000											// Timeout for initial clock synchronization in ms
#define SYNC_SLOT_PERIOD		1500											// Duration of sync slot in ms
#define MAX_CLK_DRIFT_PPM		200												// Maximum clock drift in parts per million
#define MAX_SLOT_CLK_DRIFT		(PARAM_SYNC_PERIOD*60*MAX_CLK_DRIFT_PPM)/1000	// Maximum clock drift between SYNC updates in ms
#define MIN_TX_DELAY_TIME		MAX_SLOT_CLK_DRIFT								// Minimum TX delay time in ms
#define TX_PROPAGATION_DELAY	20												// Delay for propagation of packets in ms
#define CLOCK_SYNC_DELAY		50 + TX_PROPAGATION_DELAY						// Delay during clock synchronization in ms


/*****************************************************************************
 *  Global Typedefs
 *****************************************************************************/
typedef struct
{
	uint8_t node;
	uint8_t dc;
} nodeInfo;


/*****************************************************************************
 *  Global Variable Declarations
 *****************************************************************************/
extern volatile bool activeMode;


/*****************************************************************************
 *  Global Function Declarations
 *****************************************************************************/
time_t COMMUNICATION_Init_Clk_Sync(void);
void COMMUNICATION_Sync_TRx(void);
void COMMUNICATION_Data_TRx(sensorData *sensor_data, uint8_t dc);


#endif /* COMMUNICATION_H_ */
