/*
 * duty_cycling.c
 *
 *  Created on: 24/05/2015
 *      Author: Erick Castillo
 */

#include <stdio.h>
#include "duty_cycling.h"


/******************************************************************************
 * Local Variables
 *****************************************************************************/
static float_t B_cur = INIT_B;
static float_t B_tgt = INIT_B_tgt;
static float_t param_vector[3] = {INIT_Pvec_0, INIT_Pvec_1, INIT_Pvec_2};
static float_t feature_vector[3] = {INIT_Fvec_0, INIT_Fvec_1, INIT_Fvec_2};
static float_t dc = INIT_dc;
static float_t dc_smooth = INIT_dc;
static float_t dc_real = INIT_dc;


/******************************************************************************
 * @brief Function to multiply vectors
 *****************************************************************************/
static float_t vector_mult(float_t *a, float_t *b, int n)
{
	float_t res = 0;

	for (int i = 0; i < n; i++)
	{
		res += a[i]*b[i];
	}

	return res;
}


/******************************************************************************
 * @brief Function to update the duty cycle
 *****************************************************************************/
uint8_t DUTY_CYCLING_GetDC(float_t bat_level)
{
	float_t temp = 0.0;
	float_t op1 = 0.0;
	float_t op2 = 0.0;

	// Obtain the actual battery level
	B_cur = bat_level;

	// Compute the parameter vector
	op1 = PARAM_STEP_SIZE / vector_mult(feature_vector, feature_vector, 3);
	op2 = B_cur - vector_mult(feature_vector, param_vector, 3);
	temp = op1 * op2;

	param_vector[0] = param_vector[0] + feature_vector[0]*temp;
	if (param_vector[0] <= 0) param_vector[0] = INIT_Pvec_0;
	param_vector[1] = param_vector[1] + feature_vector[1]*temp;
	if (param_vector[1] >= 0) param_vector[1] = INIT_Pvec_1;
	param_vector[2] = param_vector[2] + feature_vector[2]*temp;
	if (param_vector[2] <= 0) param_vector[2] = INIT_Pvec_2;

	// Compute the duty cycle
	dc = (B_tgt - param_vector[0]*B_cur + param_vector[2]*B_tgt) / param_vector[1];
	if (dc < PARAM_MIN_DC) 		dc = PARAM_MIN_DC;
	else if (dc > PARAM_MAX_DC) dc = PARAM_MAX_DC;

	// Update the feature vector
	feature_vector[0] = B_cur;
	feature_vector[1] = dc;
	feature_vector[2] = -B_tgt;

	// Smooth the change of the duty cycle
	dc_smooth = dc_smooth + PARAM_SMOOTHING*(dc - dc_smooth);

	// Control the variance of the duty cycle
	dc_real = PARAM_VARIANCE*dc + (1 - PARAM_VARIANCE)*dc_smooth;

	dc_real = dc_real*100;

	if (dc_real < APP_MIN_DC || dc_real > APP_MAX_DC)
	{
		printf("error: invalid duty cycle");
		return APP_MIN_DC;
	}

	return dc_real;
}
